<?xml version="1.0" encoding="UTF-8"?>

<!-- 
	This file is part of Araxis Merge.
	Copyright © 1993-2004 Araxis Ltd. All rights reserved.
-->


<xsl:stylesheet exclude-result-prefixes="#default xhtml" version="1.0" xml:lang="en" xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:mg="http://www.araxis.com/2002/Merge/Reporting" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">

    <xsl:template match="mg:fileDetails">
        <tr>
            <td><xsl:value-of select="@file"/></td>
            <td><xsl:value-of select="mg:location"/></td>
            <td><xsl:value-of select="mg:name"/></td>
            <td><xsl:value-of select="mg:lastModified"/></td>
        </tr>
    </xsl:template>


    <xsl:template name="mg:fileDetailsSection">

        <h3><strong>
                <xsl:call-template name="mg:sectionNumber">
                    <xsl:with-param name="number" select="'1'"/>
                </xsl:call-template><xsl:value-of select="$gl_filesCompared"/></strong></h3>
        <table class="bordered">
            <tr>
                <th><xsl:value-of select="$gl_numberIndicator"/></th>
                <th><xsl:value-of select="$gl_location"/></th>
                <th><xsl:value-of select="$gl_file"/></th>
                <th><xsl:value-of select="$gl_lastModified"/></th>
            </tr>
            <xsl:apply-templates select="mg:metaData/mg:fileDetails"/>
            <xsl:if test="$g_isThreeWayComparison">
                <tr>
                    <td colspan="4">
                        <xsl:copy-of select="$gl_secondFileIsCommonAncestor"/>
                    </td>
                </tr>
            </xsl:if>
        </table>
    </xsl:template>


    <xsl:template name="mg:fileChangeSummariesHelp">
        <xsl:param name="type"/>
        <td style="text-align: right;"><xsl:value-of select="mg:changeSummary[@files='1,2']/mg:changeCount[@type=$type]/@blocks"/></td>
        <td style="text-align: right;"><xsl:value-of select="mg:changeSummary[@files='1,2']/mg:changeCount[@type=$type]/@lines"/></td>
        <xsl:if test="$g_isThreeWayComparison">
            <td style="text-align: right;"><xsl:value-of select="mg:changeSummary[@files='2,3']/mg:changeCount[@type=$type]/@blocks"/></td>
            <td style="text-align: right;"><xsl:value-of select="mg:changeSummary[@files='2,3']/mg:changeCount[@type=$type]/@lines"/></td>
            <td style="text-align: right;"><xsl:value-of select="mg:changeSummary[@files='1,2,3']/mg:changeCount[@type=$type]/@blocks"/></td>
            <td style="text-align: right;"><xsl:value-of select="mg:changeSummary[@files='1,2,3']/mg:changeCount[@type=$type]/@lines"/></td>
        </xsl:if>
    </xsl:template>


    <xsl:template match="mg:changeSummaries">
        <xsl:if test="not($g_isStatisticsWindow)">

            <h3><strong>
                    <xsl:call-template name="mg:sectionNumber">
                        <xsl:with-param name="number" select="'2'"/>
                    </xsl:call-template><xsl:value-of select="$gl_comparisonSummary"/></strong></h3>
        </xsl:if>
        <table class="bordered">
            <tr>
                <th rowspan="2" style="vertical-align: bottom;"><xsl:value-of select="$gl_description"/></th>
                <th colspan="2">
                    <xsl:copy-of select="$gl_betweenFiles1And2"/>
                </th>
                <xsl:if test="$g_isThreeWayComparison">
                    <th colspan="2">
                        <xsl:copy-of select="$gl_betweenFiles2And3"/>
                    </th>
                    <th colspan="2">
                        <xsl:copy-of select="$gl_relativeToCommonAncestor"/>
                    </th>
                </xsl:if>
            </tr>
            <tr>
                <th style="text-align: right;"><xsl:value-of select="$gl_textBlocks"/></th>
                <th style="text-align: right;"><xsl:value-of select="$gl_lines"/></th>
                <xsl:if test="$g_isThreeWayComparison">
                    <th style="text-align: right;"><xsl:value-of select="$gl_textBlocks"/></th>
                    <th style="text-align: right;"><xsl:value-of select="$gl_lines"/></th>
                    <th style="text-align: right;"><xsl:value-of select="$gl_textBlocks"/></th>
                    <th style="text-align: right;"><xsl:value-of select="$gl_lines"/></th>
                </xsl:if>
            </tr>
            <tr>
                <td><xsl:value-of select="$gl_unchanged"/></td>
                <xsl:call-template name="mg:fileChangeSummariesHelp">
                    <xsl:with-param name="type" select="'unchanged'"/>
                </xsl:call-template>
            </tr>
            <tr>
                <td><xsl:value-of select="$gl_changed"/></td>
                <xsl:call-template name="mg:fileChangeSummariesHelp">
                    <xsl:with-param name="type" select="'changed'"/>
                </xsl:call-template>
            </tr>
            <tr>
                <td><xsl:value-of select="$gl_inserted"/></td>
                <xsl:call-template name="mg:fileChangeSummariesHelp">
                    <xsl:with-param name="type" select="'inserted'"/>
                </xsl:call-template>
            </tr>
            <tr>
                <td><xsl:value-of select="$gl_removed"/></td>
                <xsl:call-template name="mg:fileChangeSummariesHelp">
                    <xsl:with-param name="type" select="'removed'"/>
                </xsl:call-template>
            </tr>
            <xsl:if test="$g_isThreeWayComparison">
                <tr>
                    <td colspan="7">
                        <xsl:copy-of select="$gl_anAutomaticMergeWouldLeave"/><xsl:value-of select="mg:changeSummary[@files='1,2,3']/mg:changeCount[@type='conflicts']/@count"/><xsl:value-of select="$gl_conflicts"/></td>
                </tr>
            </xsl:if>
        </table>
    </xsl:template>

</xsl:stylesheet>