<?xml version="1.0" encoding="UTF-8"?>

<!-- 
	This file is part of Araxis Merge.
	Copyright © 1993-2006 Araxis Ltd. All rights reserved.
-->


<xsl:stylesheet exclude-result-prefixes="#default xhtml" version="1.0" xml:lang="en" xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:mg="http://www.araxis.com/2002/Merge/Reporting" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">

    <xsl:template match="mg:classes">
        <xsl:apply-templates select="mg:class"/>
    </xsl:template>


    <xsl:template match="mg:class">
        <xsl:text>span.</xsl:text><xsl:value-of select="@name"/><xsl:value-of select="../@file|../@folder"/>
        <xsl:text>, span.</xsl:text><xsl:value-of select="@name"/><xsl:value-of select="../@file|../@folder"/>
        <xsl:text> a </xsl:text>
        <xsl:text>{float: left; width: auto;</xsl:text>
        <xsl:apply-templates select="mg:cssAttribute"/>
        <xsl:text>}
</xsl:text>
        <xsl:text>span.</xsl:text><xsl:value-of select="@name"/><xsl:value-of select="../@file|../@folder"/>
        <xsl:text> a {text-decoration: underline;}
</xsl:text>
        <xsl:text>td.</xsl:text><xsl:value-of select="@name"/><xsl:value-of select="../@file|../@folder"/>
        <xsl:text> {</xsl:text>
        <xsl:apply-templates select="mg:cssAttribute"/>
        <xsl:if test="../@file and not($g_wordWrapFileComparisons)">white-space: nowrap; vertical-align: baseline;</xsl:if>
        <xsl:text>}
</xsl:text>

        <!-- to be consistent with Merge, we need another variant of the style for change block td elements that doesn't have the background colour -->
        <xsl:if test="contains(@name, 'C')">
            <xsl:text>td.nbg</xsl:text>

            <!-- "no background" --><xsl:value-of select="@name"/><xsl:value-of select="../@file|../@folder"/>
            <xsl:text> {</xsl:text>
            <xsl:apply-templates select="mg:cssAttribute[not(@name='background-color')]"/>
            <xsl:apply-templates select="../mg:class[@name='U' or @name='UU']/mg:cssAttribute[@name='background-color']"/>
            <xsl:if test="../@file and not($g_wordWrapFileComparisons)"> white-space: nowrap; vertical-align: baseline;</xsl:if>
            <xsl:text>}
</xsl:text>
        </xsl:if>
    </xsl:template>


    <xsl:template match="mg:cssAttribute"><xsl:value-of select="@name"/>
        <xsl:text>: </xsl:text><xsl:value-of select="."/>
        <xsl:text>; </xsl:text>
    </xsl:template>


    <xsl:template match="mg:cssAttribute[@name='font-family']"><xsl:value-of select="@name"/>
        <xsl:text>: "</xsl:text><xsl:value-of select="."/>
        <xsl:text>"; </xsl:text>
    </xsl:template>


    <xsl:template match="mg:rowData">

        <h3><strong>
                <xsl:call-template name="mg:sectionNumber">
                    <xsl:with-param name="number" select="'5'"/>
                </xsl:call-template><xsl:value-of select="$gl_comparisonDetail"/></strong></h3>
        <table class="mgRowGroup">
            <xsl:variable name="lineNumberWidth" select="'5em'"/>
            <xsl:variable name="lineNumberSpacing" select="'1em'"/>

            <xsl:choose>
                <xsl:when test="$g_isThreeWayComparison">
                    <col style="width: {$lineNumberWidth};"/>
                    <col style="width: {$lineNumberSpacing};"/>
                    <col width="*"/>
                    <col style="width: 1em;"/>
                    <col style="width: {$lineNumberWidth};"/>
                    <col style="width: {$lineNumberSpacing};"/>
                    <col width="*"/>
                    <col style="width: 1em;"/>
                    <col style="width: {$lineNumberWidth};"/>
                    <col style="width: {$lineNumberSpacing};"/>
                    <col width="*"/>
                </xsl:when>
                <xsl:otherwise>
                    <col style="width: {$lineNumberWidth};"/>
                    <col style="width: {$lineNumberSpacing};"/>
                    <col width="*"/>
                    <col style="width: 1em;"/>
                    <col style="width: {$lineNumberWidth};"/>
                    <col style="width: {$lineNumberSpacing};"/>
                    <col width="*"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:apply-templates select="mg:rowGroup/mg:row|mg:rowGroup/mg:omitted"/>
        </table>
    </xsl:template>


    <xsl:template match="mg:omitted">

        <xsl:choose>
            <xsl:when test="$g_isThreeWayComparison">
                <tr>
                    <td class="U1" colspan="11" style="background-color: #f5f5f5; vertical-align: middle; text-align: center; border-bottom: dashed 1px {$gs_bgBorder}; border-top: dashed 1px {$gs_bgBorder};">(<xsl:value-of select="@rows"/> unchanged lines omitted)</td>
                </tr>
            </xsl:when>
            <xsl:otherwise>
                <tr>
                    <td class="U1" colspan="7" style="background-color: #f5f5f5; vertical-align: middle; text-align: center; border-bottom: dashed 1px {$gs_bgBorder}; border-top: dashed 1px {$gs_bgBorder};">(<xsl:value-of select="@rows"/> unchanged lines omitted)</td>
                </tr>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <xsl:template match="mg:row">
        <tr>
            <xsl:call-template name="mg:line">
                <xsl:with-param name="node" select="mg:line[@file='1']"/>
            </xsl:call-template>
            <td>&#160;</td>
            <xsl:call-template name="mg:line">
                <xsl:with-param name="node" select="mg:line[@file='2']"/>
            </xsl:call-template>
            <xsl:if test="$g_isThreeWayComparison">
                <td>&#160;</td>
                <xsl:call-template name="mg:line">
                    <xsl:with-param name="node" select="mg:line[@file='3']"/>
                </xsl:call-template>
            </xsl:if>
        </tr>
    </xsl:template>


    <xsl:template name="mg:line">
        <xsl:param name="node"/>

        <xsl:choose>
            <xsl:when test="not($node)">
                <td colspan="3" style="background-color: #f5f5f5;">&#160;</td>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="nbgPrefix">
                    <xsl:if test="contains($node/@class, 'C')">nbg</xsl:if>
                </xsl:variable>
                <td class="{$node/@class}{$node/@file}" style="text-align: right;"><xsl:value-of select="$node/@number"/></td>
                <td class="{$node/@class}{$node/@file}" style="text-decoration: none;">&#160;</td>
                <td class="{$nbgPrefix}{$node/@class}{$node/@file}">
                    <xsl:apply-templates select="$node/mg:segment"/>
                </td>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <!-- this handles insertion points, which are represented by segments with no content -->

    <xsl:template match="mg:segment[not(node())]"><span class="{@class}{../@file}">
            <div class="IP">
                <xsl:text> </xsl:text>
            </div>
        </span>
    </xsl:template>


    <xsl:template match="mg:segment[node()]"><span class="{@class}{../@file}">
            <xsl:apply-templates select="mg:s|mg:t|text()"/>
            <xsl:if test="mg:cr|mg:lf and $g_showLineEndings"><span class="lineEndings">
                    <xsl:apply-templates select="mg:cr|mg:lf"/>
                </span>
            </xsl:if>
        </span>
    </xsl:template>


    <xsl:template match="mg:s">
            <!-- The HTML spec says that user agents should strip whitespace immediately after an 
            opening element or before a closing element, so we output a non-breaking space instead
            of a breaking space. As all lines are now output in short segments, this doesn't have the
            undesirable side-effect of preventing lines from breaking. -->
        <xsl:text>&#160;</xsl:text>
    </xsl:template>


    <xsl:template match="mg:t">
        <xsl:text>»</xsl:text>
    </xsl:template>


    <xsl:template match="mg:cr">
        <xsl:text> CR</xsl:text>
    </xsl:template>


    <xsl:template match="mg:lf">
        <xsl:text> LF</xsl:text>
    </xsl:template>

</xsl:stylesheet>
