<?xml version="1.0" encoding="UTF-8"?>

<!-- 
	This file is part of Araxis Merge.
	Copyright © 1993-2004 Araxis Ltd. All rights reserved.
-->


<xsl:stylesheet exclude-result-prefixes="#default xhtml" version="1.0" xml:lang="en" xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:mg="http://www.araxis.com/2002/Merge/Reporting" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">

    <xsl:template match="mg:folderDetails">
        <tr>
            <td><xsl:value-of select="@folder"/></td>
            <td><xsl:value-of select="mg:location"/></td>
            <td><xsl:value-of select="mg:name"/></td>
        </tr>
    </xsl:template>


    <xsl:template name="mg:folderDetailsSection">

        <h3><strong>
                <xsl:call-template name="mg:sectionNumber">
                    <xsl:with-param name="number" select="'1'"/>
                </xsl:call-template><xsl:value-of select="$gl_foldersCompared"/></strong></h3>
        <table class="bordered">
            <tr>
                <th><xsl:value-of select="$gl_numberIndicator"/></th>
                <th><xsl:value-of select="$gl_location"/></th>
                <th><xsl:value-of select="$gl_folder"/></th>
            </tr>
            <xsl:apply-templates select="mg:metaData/mg:folderDetails"/>
            <xsl:if test="$g_isThreeWayComparison">
                <tr>
                    <td colspan="4">
                        <xsl:copy-of select="$gl_secondFolderIsCommonAncestor"/>
                    </td>
                </tr>
            </xsl:if>
        </table>
    </xsl:template>


    <xsl:template name="mg:folderChangeSummariesHelpForFilesAndFileLines">
        <xsl:param name="type"/>
        <td>
            <xsl:call-template name="mg:gl_x_lines_in_y_pairs_of_type_files">
                <xsl:with-param name="x" select="mg:changeSummary[@folders='1,2']/mg:changeCount[@type=$type]/@fileLines"/>
                <xsl:with-param name="y" select="mg:changeSummary[@folders='1,2']/mg:changeCount[@type=$type]/@files"/>
                <xsl:with-param name="type" select="$type"/>
                <xsl:with-param name="pairs" select="$type='changed' or $type='unchanged'"/>
            </xsl:call-template>
        </td>
        <xsl:if test="$g_isThreeWayComparison">
            <td>
                <xsl:call-template name="mg:gl_x_lines_in_y_pairs_of_type_files">
                    <xsl:with-param name="x" select="mg:changeSummary[@folders='2,3']/mg:changeCount[@type=$type]/@fileLines"/>
                    <xsl:with-param name="y" select="mg:changeSummary[@folders='2,3']/mg:changeCount[@type=$type]/@files"/>
                    <xsl:with-param name="type" select="$type"/>
                    <xsl:with-param name="pairs" select="$type='changed' or $type='unchanged'"/>
                </xsl:call-template>
            </td>
            <td>
                <xsl:call-template name="mg:gl_x_lines_in_y_pairs_of_type_files">
                    <xsl:with-param name="x" select="mg:changeSummary[@folders='1,3']/mg:changeCount[@type=$type]/@fileLines"/>
                    <xsl:with-param name="y" select="mg:changeSummary[@folders='1,3']/mg:changeCount[@type=$type]/@files"/>
                    <xsl:with-param name="type" select="$type"/>
                    <xsl:with-param name="pairs" select="$type='changed' or $type='unchanged'"/>
                </xsl:call-template>
            </td>
            <xsl:if test="@set='all'">
                <td>
                    <xsl:call-template name="mg:gl_y_type_files">
                        <xsl:with-param name="y" select="mg:changeSummary[@folders='1,2,3']/mg:changeCount[@type=$type]/@files"/>
                        <xsl:with-param name="type" select="$type"/>
                    </xsl:call-template>
                </td>
            </xsl:if>
        </xsl:if>
    </xsl:template>


    <xsl:template name="mg:folderChangeSummariesHelpForBlocksAndLines">
        <xsl:param name="type"/>
        <td style="text-align: right;">
            <xsl:value-of select="mg:changeSummary[@folders='1,2']/mg:changeCount[@type=$type]/@lines"/></td>
        <td style="text-align: right;"><xsl:value-of select="mg:changeSummary[@folders='1,2']/mg:changeCount[@type=$type]/@blocks"/></td>
        <xsl:if test="$g_isThreeWayComparison">
            <td style="text-align: right;">
                <xsl:value-of select="mg:changeSummary[@folders='2,3']/mg:changeCount[@type=$type]/@lines"/></td>
            <td style="text-align: right;"><xsl:value-of select="mg:changeSummary[@folders='2,3']/mg:changeCount[@type=$type]/@blocks"/></td>
            <td style="text-align: right;">
                <xsl:value-of select="mg:changeSummary[@folders='1,3']/mg:changeCount[@type=$type]/@lines"/></td>
            <td style="text-align: right;"><xsl:value-of select="mg:changeSummary[@folders='1,3']/mg:changeCount[@type=$type]/@blocks"/></td>
        </xsl:if>
    </xsl:template>


    <xsl:template name="mg:changeSummaryNotes">
        <xsl:if test="$g_isStatisticsWindow and (not($g_comparisonThoroughness='1') or $g_comparisonThoroughness = '0')">

            <h3><xsl:value-of select="$gl_notes"/></h3>
        </xsl:if>
        <xsl:if test="not($g_comparisonThoroughness='1')">
            <xsl:copy-of select="$gl_lineCountsNotShown"/>
        </xsl:if>
        <xsl:if test="$g_comparisonThoroughness = '0'">
            <xsl:copy-of select="$gl_detailedComparisonResultsTableNotAvailable"/>
        </xsl:if>
    </xsl:template>


    <xsl:template match="mg:changeSummaries" mode="folder">

        <h3><strong>

                <xsl:choose>
                    <xsl:when test="@set='all'">
                        <xsl:if test="not($g_isStatisticsWindow)">
                            <xsl:call-template name="mg:sectionNumber">
                                <xsl:with-param name="number" select="'2'"/>
                            </xsl:call-template>
                        </xsl:if><xsl:value-of select="$gl_summaryForAllFiles"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test="not($g_isStatisticsWindow)">
                            <xsl:call-template name="mg:sectionNumber">
                                <xsl:with-param name="number" select="'3'"/>
                            </xsl:call-template>
                        </xsl:if><xsl:value-of select="$gl_summaryForSelectedFiles"/>
                    </xsl:otherwise>
                </xsl:choose>
            </strong></h3>
        <xsl:if test="not($g_isStatisticsWindow)">
            <xsl:call-template name="mg:changeSummaryNotes"/>
        </xsl:if>

        <xsl:choose>
            <xsl:when test="@set = 'selected' and not($g_rowsSelected)">
                <p><xsl:value-of select="$gl_noFilesWereSelected"/></p>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="mg:FilesAndFileLinesTable"/>
                <xsl:if test="not($g_comparisonThoroughness = '0')">
                    <xsl:call-template name="mg:BlocksAndLinesTable"/>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="@set='selected' and $g_isStatisticsWindow">
            <xsl:call-template name="mg:changeSummaryNotes"/>
        </xsl:if>
    </xsl:template>


    <xsl:template name="mg:FilesAndFileLinesTable">
        <table class="bordered">
            <tr>
                <th><xsl:value-of select="$gl_betweenFolders1And2"/></th>
                <xsl:if test="$g_isThreeWayComparison">
                    <th><xsl:value-of select="$gl_betweenFolders2And3"/></th>
                    <th><xsl:value-of select="$gl_betweenFolders1And3"/></th>
                    <xsl:if test="@set='all'">
                        <th><xsl:copy-of select="$gl_relativeToCommonAncestor"/></th>
                    </xsl:if>
                </xsl:if>
            </tr>
            <tr>
                <xsl:call-template name="mg:folderChangeSummariesHelpForFilesAndFileLines">
                    <xsl:with-param name="type" select="'unchanged'"/>
                </xsl:call-template>
            </tr>
            <tr>
                <xsl:call-template name="mg:folderChangeSummariesHelpForFilesAndFileLines">
                    <xsl:with-param name="type" select="'changed'"/>
                </xsl:call-template>
            </tr>
            <tr>
                <xsl:call-template name="mg:folderChangeSummariesHelpForFilesAndFileLines">
                    <xsl:with-param name="type" select="'inserted'"/>
                </xsl:call-template>
            </tr>
            <tr>
                <xsl:call-template name="mg:folderChangeSummariesHelpForFilesAndFileLines">
                    <xsl:with-param name="type" select="'removed'"/>
                </xsl:call-template>
            </tr>
        </table>
    </xsl:template>


    <xsl:template name="mg:BlocksAndLinesTable">
        <table class="bordered">
            <tr>
                <th rowspan="2" style="vertical-align: bottom;"><xsl:value-of select="$gl_description"/></th>
                <th colspan="2"><xsl:value-of select="$gl_betweenFolders1And2"/></th>
                <xsl:if test="$g_isThreeWayComparison">
                    <th colspan="2"><xsl:value-of select="$gl_betweenFolders2And3"/></th>
                    <th colspan="2"><xsl:value-of select="$gl_betweenFolders1And3"/></th>
                </xsl:if>
            </tr>
            <tr>
                <th style="text-align: right;"><xsl:value-of select="$gl_lines"/></th>
                <th style="text-align: right;"><xsl:value-of select="$gl_textBlocks"/></th>
                <xsl:if test="$g_isThreeWayComparison">
                    <th style="text-align: right;"><xsl:value-of select="$gl_lines"/></th>
                    <th style="text-align: right;"><xsl:value-of select="$gl_textBlocks"/></th>
                    <th style="text-align: right;"><xsl:value-of select="$gl_lines"/></th>
                    <th style="text-align: right;"><xsl:value-of select="$gl_textBlocks"/></th>
                </xsl:if>
            </tr>
            <tr>
                <td><xsl:value-of select="$gl_unchanged"/></td>
                <xsl:call-template name="mg:folderChangeSummariesHelpForBlocksAndLines">
                    <xsl:with-param name="type" select="'unchanged'"/>
                </xsl:call-template>
            </tr>
            <tr>
                <td><xsl:value-of select="$gl_changed"/></td>
                <xsl:call-template name="mg:folderChangeSummariesHelpForBlocksAndLines">
                    <xsl:with-param name="type" select="'changed'"/>
                </xsl:call-template>
            </tr>
            <tr>
                <td><xsl:value-of select="$gl_inserted"/></td>
                <xsl:call-template name="mg:folderChangeSummariesHelpForBlocksAndLines">
                    <xsl:with-param name="type" select="'inserted'"/>
                </xsl:call-template>
            </tr>
            <tr>
                <td><xsl:value-of select="$gl_removed"/></td>
                <xsl:call-template name="mg:folderChangeSummariesHelpForBlocksAndLines">
                    <xsl:with-param name="type" select="'removed'"/>
                </xsl:call-template>
            </tr>
        </table>
    </xsl:template>

</xsl:stylesheet>