<?xml version="1.0" encoding="UTF-8"?>

<!-- 
	This file is part of Araxis Merge.
	Copyright © 1993-2006 Araxis Ltd. All rights reserved.
-->


<xsl:stylesheet exclude-result-prefixes="#default xhtml" version="1.0" xml:lang="en" xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:mg="http://www.araxis.com/2002/Merge/Reporting" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">

    <xsl:template match="mg:rowData" mode="folder">

        <h3><strong>
                <xsl:call-template name="mg:sectionNumber">
                    <xsl:with-param name="number" select="'6'"/>
                </xsl:call-template><xsl:value-of select="$gl_comparisonDetail"/></strong></h3>
        <table class="mgRowGroupFolder" style="padding: 1px 0 1px 0;">
            <xsl:variable name="spacing" select="'.8em'"/>
            <xsl:variable name="changeCountWidth" select="'2.5em'"/>

            <xsl:choose>
                <xsl:when test="$g_isThreeWayComparison">
                    <xsl:variable name="itemWidth" select="'*'"/>
                    <col width="width: {$itemWidth};"/>
                    <xsl:if test="$g_showChanges">
                        <col style="width: {$changeCountWidth};"/>
                    </xsl:if>
                    <col style="width: {$spacing};"/>
                    <col width="width: {$itemWidth};"/>
                    <xsl:if test="$g_showChanges">
                        <col style="width: {$changeCountWidth};"/>
                    </xsl:if>
                    <col style="width: {$spacing};"/>
                    <col width="width: {$itemWidth};"/>
                    <xsl:if test="$g_showChanges">
                        <col style="width: {$changeCountWidth};"/>
                    </xsl:if>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="itemWidth" select="'*'"/>
                    <col width="width: {$itemWidth};"/>
                    <xsl:if test="$g_showChanges">
                        <col style="width: {$changeCountWidth};"/>
                    </xsl:if>
                    <col style="width: {$spacing};"/>
                    <col width="width: {$itemWidth};"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:if test="$g_fileComparisonLinks">
                <col style="width: 8em;"/>
            </xsl:if>
            <xsl:apply-templates mode="folder" select="mg:row"/>
        </table>
    </xsl:template>


    <xsl:template match="mg:row" mode="folder">
        <tr>
            <xsl:call-template name="mg:fileOrFolder">
                <xsl:with-param name="node" select="*[@folder='1']"/>
                <xsl:with-param name="column" select="'1'"/>
            </xsl:call-template>
            <td>&#160;</td>
            <xsl:call-template name="mg:fileOrFolder">
                <xsl:with-param name="node" select="*[@folder='2']"/>
                <xsl:with-param name="column" select="'2'"/>
            </xsl:call-template>
            <xsl:if test="$g_isThreeWayComparison">
                <td>&#160;</td>
                <xsl:call-template name="mg:fileOrFolder">
                    <xsl:with-param name="node" select="*[@folder='3']"/>
                    <xsl:with-param name="column" select="'3'"/>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$g_fileComparisonLinks">
                <td>
                    <xsl:text>&#160;&#160;</xsl:text>
                    <xsl:if test="@url"><a href="{@url}" title="{$gl_linkToDetailedFileComparison}"><xsl:value-of select="$gl_reportLinkText"/><xsl:value-of select="@reportId"/></a>
                    </xsl:if>
                    <xsl:if test="@error"><xsl:copy-of select="$gl_errorFilesTooLargeToCreateReport"/></xsl:if>
                </td>
            </xsl:if>
        </tr>
    </xsl:template>


    <xsl:template name="mg:fileOrFolder">
        <xsl:param name="node"/>
        <xsl:param name="column"/>

        <xsl:choose>
            <xsl:when test="not($node)">
                <td style="background-color: #f5f5f5;">&#160;</td>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="leftPadding" select="16 * $node/@level"/>
                <td class="{$node/@class}{$node/@folder}">
                    <div class="mgFldrIcon" style="padding-left: {$leftPadding}px;">
                        <img alt="" class="mgFldrIcon" src="{$node/@icon}"/>
                    </div><span class="left">
                        <xsl:call-template name="mg:filename">
                            <xsl:with-param name="node" select="$node"/>
                        </xsl:call-template>
                    </span>
                    <xsl:if test="$g_showTimestamps"><span class="right">&#160;<xsl:value-of select="$node/@size"/>, <xsl:value-of select="$node/@timestamp"/></span>
                    </xsl:if>
                </td>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="$g_showChanges and ($g_isThreeWayComparison or $column='1')">
            <xsl:element name="td">
                <xsl:attribute name="class"><xsl:value-of select="string($node/@class)"/><xsl:value-of select="string($node/@folder)"/>
                </xsl:attribute>
                <xsl:attribute name="style">
                    <xsl:if test="not($node/@class)">background-color: #f5f5f5; </xsl:if>
                    <xsl:text>text-align: right; text-decoration: none;</xsl:text>
                </xsl:attribute>
                <xsl:text>&#160;</xsl:text>
                <xsl:if test="$node/@changeCount"><xsl:value-of select="$node/@changeCount"/>
                </xsl:if>
            </xsl:element>
        </xsl:if>
    </xsl:template>


    <xsl:template name="mg:filename">
        <xsl:param name="node"/>
        <xsl:element name="span">
            <xsl:if test="@selected='true'">
                <xsl:attribute name="class">selected</xsl:attribute>
            </xsl:if>

            <xsl:choose>
                <xsl:when test="@url"><a href="{@url}" title="{$gl_linkToDetailedFileComparison}"><xsl:value-of select="$node/@name"/></a>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="$node/@name"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:element>
    </xsl:template>

</xsl:stylesheet>