<?xml version="1.0" encoding="UTF-8"?>

<!-- 
	This file is part of Araxis Merge.
	Copyright © 1993-2004 Araxis Ltd. All rights reserved.
-->

<xsl:stylesheet exclude-result-prefixes="#default xhtml" version="1.0" xml:lang="en" xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:mg="http://www.araxis.com/2002/Merge/Reporting" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">

    <xsl:template match="mg:regexps">

        <h3><strong>

                <xsl:choose>
                    <xsl:when test="$g_isFolderComparison">
                        <xsl:call-template name="mg:sectionNumber">
                            <xsl:with-param name="number" select="'5'"/>
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="mg:sectionNumber">
                            <xsl:with-param name="number" select="'4'"/>
                        </xsl:call-template>
                    </xsl:otherwise>
                </xsl:choose><xsl:value-of select="$gl_activeRegularExpressions"/></strong></h3>

        <xsl:choose>
            <xsl:when test="mg:regexp[@enabled='true']">
                <table class="bordered">
                    <tr>
                        <th><xsl:value-of select="$gl_expression"/></th>
                        <th><xsl:value-of select="$gl_description"/></th>
                    </tr>
                    <xsl:apply-templates select="mg:regexp[@enabled='true']"/>
                </table>
            </xsl:when>
            <xsl:otherwise>
                <p><xsl:value-of select="$gl_noRegularExpressionsWereActive"/></p>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <xsl:template match="mg:regexp">
        <tr>
            <td><code><xsl:value-of select="mg:expression"/></code></td>
            <td><xsl:value-of select="mg:description"/></td>
        </tr>
    </xsl:template>


    <xsl:template match="mg:options">

        <h3><strong>

                <xsl:choose>
                    <xsl:when test="$g_isFolderComparison">
                        <xsl:call-template name="mg:sectionNumber">
                            <xsl:with-param name="number" select="'4'"/>
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="mg:sectionNumber">
                            <xsl:with-param name="number" select="'3'"/>
                        </xsl:call-template>
                    </xsl:otherwise>
                </xsl:choose><xsl:value-of select="$gl_comparisonOptions"/></strong></h3>
        <table class="bordered" style="width: 55em;">
            <xsl:if test="$g_isFolderComparison">
                <tr>
                    <th><xsl:value-of select="$gl_comparisonMethod"/></th>
                    <td>
                        <xsl:apply-templates select="mg:option[@name='clThoroughComparison']"/>
                    </td>
                </tr>
                <tr>
                    <th><xsl:value-of select="$gl_depth"/></th>
                    <td>
                        <xsl:apply-templates select="mg:option[@name='clTopLevelFilesOnly']"/>
                    </td>
                </tr>
            </xsl:if>
            <xsl:if test="not($g_isFolderComparison) or mg:option[@name='clThoroughComparison']/text()='1'">
                <tr>
                    <th><xsl:value-of select="$gl_whitespace"/></th>
                    <td>
                        <xsl:apply-templates select="mg:option[@name='clIgnWhitespace']"/>
                    </td>
                </tr>
                <tr>
                    <th><xsl:value-of select="$gl_characterCase"/></th>
                    <td>
                        <xsl:apply-templates select="mg:option[@name='clIgnoreCase']"/>
                    </td>
                </tr>
                <tr>
                    <th><xsl:value-of select="$gl_lineEndings"/></th>
                    <td>
                        <xsl:apply-templates select="mg:option[@name='clIgnoreLineEndings']"/>
                    </td>
                </tr>
                <xsl:if test="not($g_isFolderComparison)">
                    <tr>
                        <th><xsl:value-of select="$gl_crLfCharacters"/></th>
                        <td>
                            <xsl:apply-templates select="mg:option[@name='clHideCRLF']"/>
                        </td>
                    </tr>
                </xsl:if>
            </xsl:if>
            <xsl:if test="$g_isFolderComparison">
                
                <xsl:apply-templates select="mg:option[@name='csInclude']"/>
                
                <xsl:apply-templates select="mg:option[@name='csExclude']"/>

                <tr>
                    <th><xsl:value-of select="$gl_unchangedFiles"/></th>
                    <td>
                        <xsl:apply-templates select="mg:option[@name='clShowUnchanged']"/>
                    </td>
                </tr>
                <tr>
                    <th><xsl:value-of select="$gl_timestampsAndSizes"/></th>
                    <td>
                        <xsl:apply-templates select="mg:option[@name='clShowFileStamps']"/>
                    </td>
                </tr>
                <tr>
                    <th><xsl:value-of select="$gl_changeCounts"/></th>
                    <td>
                        <xsl:apply-templates select="mg:option[@name='clShowChangesColumn']"/>
                    </td>
                </tr>
            </xsl:if>
        </table>
        <xsl:apply-templates select="mg:regexps"/>
    </xsl:template>


    <xsl:template match="mg:option[@name='clTopLevelFilesOnly']">

        <xsl:choose>
            <xsl:when test="text()='0'"><xsl:value-of select="$gl_allFilesCompared"/></xsl:when>
            <xsl:when test="text()='1'"><xsl:value-of select="$gl_onlyFilesInTopLevelCompared"/></xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="mg:option[@name='csExclude']">
      <tr>
        <th><xsl:value-of select="$gl_ignore"/></th>
        <td>
          <xsl:value-of select="$gl_filesMatchingThePattern"/><code><xsl:value-of select="text()"/></code><xsl:value-of select="$gl_areIgnored"/>
        </td>
      </tr>
    </xsl:template>

    <xsl:template match="mg:option[@name='csInclude']">
      <tr>
        <th><xsl:value-of select="$gl_include"/></th>
        <td>
          <xsl:value-of select="$gl_filesMatchingThePattern"/><code><xsl:value-of select="text()"/></code><xsl:value-of select="$gl_areIncludedInTheComparison"/>
        </td>
      </tr>
    </xsl:template>

    <xsl:template match="mg:option[@name='clShowUnchanged']">

        <xsl:choose>
            <xsl:when test="text()='0'"><xsl:value-of select="$gl_notShownInTheComparisonDetail"/></xsl:when>
            <xsl:when test="text()='1'"><xsl:value-of select="$gl_shownInTheComparisonDetail"/></xsl:when>
        </xsl:choose>
    </xsl:template>


    <xsl:template match="mg:option[@name='clThoroughComparison']">
        <xsl:choose>
            <xsl:when test="text()='0'"><xsl:value-of select="$gl_fileTimestampsAndSizes"/></xsl:when>
            <xsl:when test="text()='1'">

                <xsl:choose>
                    <xsl:when test="../mg:option[@name='clQuickDiffForLargeFiles']/text()='0'"><xsl:value-of select="$gl_comparisonRules"/>
                    </xsl:when>
                    <xsl:otherwise><xsl:value-of select="$gl_filesSmallerThan"/><xsl:value-of select="../mg:option[@name='clQuickDiffLimit']"/><xsl:value-of select="$gl_byteByByte"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="text()='2'">

                <xsl:choose>
                    <xsl:when test="../mg:option[@name='clQuickDiffForLargeFiles']/text()='0'"><xsl:value-of select="$gl_differingSizesOrTimestamps"/></xsl:when>
                    <xsl:otherwise><xsl:value-of select="$gl_identicalSizesAndTimestamps"/><xsl:value-of select="../mg:option[@name='clQuickDiffLimit']"/><xsl:value-of select="$gl_forLargerFiles"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
        </xsl:choose>
    </xsl:template>


    <xsl:template match="mg:option[@name='clShowFileStamps']">

        <xsl:choose>
            <xsl:when test="text()='0'"><xsl:value-of select="$gl_notShownInTheComparisonDetail"/></xsl:when>
            <xsl:when test="text()='1'"><xsl:value-of select="$gl_shownInTheComparisonDetail"/></xsl:when>
        </xsl:choose>
    </xsl:template>


    <xsl:template match="mg:option[@name='clShowChangesColumn']">

        <xsl:choose>
            <xsl:when test="text()='0'"><xsl:value-of select="$gl_notShownInTheComparisonDetail"/></xsl:when>
            <xsl:when test="text()='1'"><xsl:value-of select="$gl_shownInTheComparisonDetail"/></xsl:when>
        </xsl:choose>
    </xsl:template>


    <xsl:template match="mg:option[@name='clIgnWhitespace']">

        <xsl:choose>
            <xsl:when test="text()='0'"><xsl:value-of select="$gl_whitespaceSignificant"/></xsl:when>
            <xsl:when test="text()='1'"><xsl:value-of select="$gl_whitespaceWithinLinesIgnored"/></xsl:when>
            <xsl:when test="text()='2'"><xsl:value-of select="$gl_whitespaceAtStartOfLinesIgnored"/></xsl:when>
        </xsl:choose>
    </xsl:template>


    <xsl:template match="mg:option[@name='clIgnoreCase']">

        <xsl:choose>
            <xsl:when test="text()='0'"><xsl:value-of select="$gl_characterCaseSignificant"/></xsl:when>
            <xsl:when test="text()='1'"><xsl:value-of select="$gl_characterCaseIgnored"/></xsl:when>
        </xsl:choose>
    </xsl:template>


    <xsl:template match="mg:option[@name='clIgnoreLineEndings']">

        <xsl:choose>
            <xsl:when test="text()='0'">
                <xsl:copy-of select="$gl_lineEndingsSignificant"/>
            </xsl:when>
            <xsl:when test="text()='1'">
                <xsl:copy-of select="$gl_lineEndingsIgnored"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>


    <xsl:template match="mg:option[@name='clHideCRLF']">

        <xsl:choose>
            <xsl:when test="text()='0'"><xsl:value-of select="$gl_shownInTheComparisonDetail"/></xsl:when>
            <xsl:when test="text()='1'"><xsl:value-of select="$gl_notShownInTheComparisonDetail"/></xsl:when>
        </xsl:choose>
    </xsl:template>

</xsl:stylesheet>