<?xml version="1.0" encoding="UTF-8"?>

<!-- 
	This file is part of Araxis Merge.
	Copyright © 1993-2004 Araxis Ltd. All rights reserved.
-->


<xsl:stylesheet version="1.0" xml:lang="en" xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:mg="http://www.araxis.com/2002/Merge/Reporting" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">

    <!-- include additional templates -->
    <xsl:include href="MgOptions.xslt"/>
    <xsl:include href="MgFileMetaData.xslt"/>
    <xsl:include href="MgFileRowData.xslt"/>
    <xsl:include href="MgFolderMetaData.xslt"/>
    <xsl:include href="MgFolderRowData.xslt"/>
    <xsl:include href="MgFileSlideshow.xslt"/>

    <!-- define the sort of text that will be generated -->
    <xsl:output doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="DTD/xhtml1-strict.dtd" encoding="UTF-8" indent="yes" media-type="text/html" method="xml" omit-xml-declaration="no" version="1.0"/>

    <!-- true if this is a 3-way comparison -->
    <xsl:variable name="g_isThreeWayComparison" select="/mg:report/mg:metaData/mg:fileDetails[@file='3'] | /mg:report/mg:metaData/mg:folderDetails[@folder='3']"/>

    <!-- true if this is a folder comparison -->
    <xsl:variable name="g_isFolderComparison" select="contains(/mg:report/@type, 'Folder')"/>

    <!-- true if line endings are to be shown -->
    <xsl:variable name="g_showLineEndings" select="string(/mg:report/mg:metaData/mg:options/mg:option[@name='clHideCRLF'])='0'"/>

    <!-- comparison thoroughness level -->
    <xsl:variable name="g_comparisonThoroughness" select="string(/mg:report/mg:metaData/mg:options/mg:option[@name='clThoroughComparison'])"/>

    <!-- true if file timestamps are to be shown for folder comparisons -->
    <xsl:variable name="g_showTimestamps" select="string(/mg:report/mg:metaData/mg:options/mg:option[@name='clShowFileStamps'])='1'"/>

    <!-- true if change counts are to be shown for folder comparisons -->
    <xsl:variable name="g_showChanges" select="string(/mg:report/mg:metaData/mg:options/mg:option[@name='clShowChangesColumn'])='1'"/>

    <!-- true if file comparisons should be word-wrapped  -->
    <xsl:variable name="g_wordWrapFileComparisons" select="string(/mg:report/mg:metaData/mg:options/mg:option[@name='clReportHtmlFileComparison_WrapLines'])='1' or not(/mg:report/mg:metaData/mg:options/mg:option[@name='clReportHtmlFileComparison_WrapLines'])"/>

    <!-- true if there are any file comparisons linked to from (this) folder comparison report -->
    <xsl:variable name="g_fileComparisonLinks" select="/mg:report/mg:rowData/mg:row[@url or @error]"/>

    <!-- true if there are any comparisons rows in this folder comparison report are selected -->
    <xsl:variable name="g_rowsSelected" select="string(/mg:report/mg:metaData/mg:changeSummaries[@set='selected']/@fileCount) != '0'"/>

    <!-- true if this is a file or folder statistics window -->
    <xsl:variable name="g_isStatisticsWindow" select="/mg:report[@type='FileComparisonStatistics'] or /mg:report[@type='FolderComparisonStatistics']"/>

    <!-- colours used in CSS -->
    <xsl:variable name="gs_bgBorder" select="'#a0a0a0'"/>
    <xsl:variable name="gs_bgHead" select="'#e5e5e5'"/>
    <xsl:variable name="gs_bgGroup" select="'#f5f5f5'"/>

    <xsl:template match="mg:report[@type='FileComparison']">
        <html>
            <xsl:call-template name="mg:head"/>
            <body>
                <xsl:call-template name="mg:pageTitle"/>
                <xsl:call-template name="mg:preamble"/>
                <xsl:call-template name="mg:fileDetailsSection"/>
                <xsl:apply-templates select="mg:metaData/mg:changeSummaries"/>
                <xsl:apply-templates select="mg:metaData/mg:options"/>
                <xsl:apply-templates select="mg:rowData"/>
                <xsl:call-template name="mg:pageFooter"/>
            </body>
        </html>
    </xsl:template>


    <xsl:template match="mg:report[@type='FileComparisonStatistics']">
        <html>
            <xsl:call-template name="mg:headStatistics"/>
            <body>
                <div id="CopySection">

                    <!-- <xsl:call-template name="mg:fileDetailsSection" /> -->
                    <xsl:apply-templates select="mg:metaData/mg:changeSummaries"/>
                    <xsl:call-template name="mg:statisticsActions"/>
                </div>
            </body>
        </html>
    </xsl:template>


    <xsl:template match="mg:report[@type='FolderComparison']">
        <html>
            <xsl:call-template name="mg:head"/>
            <body>
                <xsl:call-template name="mg:pageTitle"/>
                <xsl:call-template name="mg:preamble"/>
                <xsl:call-template name="mg:folderDetailsSection"/>
                <xsl:apply-templates mode="folder" select="mg:metaData/mg:changeSummaries"/>
                <xsl:apply-templates select="mg:metaData/mg:options"/>
                <xsl:apply-templates mode="folder" select="mg:rowData"/>
                <xsl:call-template name="mg:pageFooter"/>
            </body>
        </html>
    </xsl:template>


    <xsl:template match="mg:report[@type='FolderComparisonStatistics']">
        <html>
            <xsl:call-template name="mg:headStatistics"/>
            <body>
                <div id="CopySection">
                    <xsl:apply-templates mode="folder" select="mg:metaData/mg:changeSummaries"/>
                    <xsl:call-template name="mg:statisticsActions"/>
                </div>
            </body>
        </html>
    </xsl:template>


    <xsl:template match="mg:report[@type='FileSlideshowSummary']">
        <html>
            <xsl:call-template name="mg:head"/>
            <body>
                <xsl:call-template name="mg:pageTitleSlideshow"/>
                <xsl:call-template name="mg:preamble"/>
                <xsl:call-template name="mg:fileDetailsSection"/>
                <xsl:apply-templates select="mg:metaData/mg:changeSummaries"/>
                <xsl:apply-templates select="mg:metaData/mg:options"/>
                <xsl:call-template name="mg:pageNavFooterSlideshow"/>
                <xsl:call-template name="mg:pageFooter"/>
            </body>
        </html>
    </xsl:template>


    <xsl:template match="mg:report[@type='FileSlideshowSlide']">
        <html>
            <xsl:call-template name="mg:head"/>
            <body>
                <xsl:call-template name="mg:pageTitleSlideshow"/>
                <xsl:apply-templates mode="img" select="mg:metaData/mg:slide"/>
                <xsl:call-template name="mg:pageNavFooterSlideshow"/>
                <xsl:call-template name="mg:pageFooter"/>
            </body>
        </html>
    </xsl:template>


    <xsl:template name="mg:statisticsActions">
        <script language="JavaScript" type="text/javascript">
            function onCopyToClipboard()
            {
              var range = document.body.createTextRange();
              range.moveToElementText(document.all.item("CopySection"));
              range.execCommand("Copy");
              window.event.returnValue = false;
            }
            function onPrint()
            {
              document.execCommand("Print", true);
              window.event.returnValue = false;
            }
            function onSaveAs()
            {
              document.execCommand("SaveAs", true, "MergeStatistics.html");
              window.event.returnValue = false;
            }      
          </script>
        <p class="copyright" style="margin-top: 15px;">
            <input onclick="onCopyToClipboard()" type="button" value="{$gl_copyButton}"/>
            <xsl:text> </xsl:text>
            <input onclick="onPrint()" type="button" value="{$gl_printButton}"/>
            <xsl:text> </xsl:text>
            <input onclick="onSaveAs()" type="button" value="{$gl_saveAsButton}"/>
        </p>
    </xsl:template>


    <xsl:template name="mg:head">
        <head>
            <meta content="text/html; charset={$outputEncoding}" http-equiv="Content-Type"/>
            <xsl:if test="/mg:report/mg:metaData/mg:title">
                <title>
                    <xsl:call-template name="mg:reportTitleText"/>
                </title>
            </xsl:if>
            <style type="text/css">
body { background: #fff;  color: #000; margin: 0px 14px 14px 14px; }
h1, h2, h3, h4, h5 {
	padding: 0em;
	margin: 1.5em 0em .25em 0em;
	text-align: left;
	font-weight: normal;
	font-family: Arial, Helvetica, sans-serif;
	font-size: 70%;
	max-width: 55em;
}
body, h4, h5, p, ol, ul, li, td, th { font-family: <xsl:value-of select="$gl_cssTextFontFamily"/>; text-align: left; }

h4, h5, p, ol, ul, li { font-size: 70%; }
input {
  font-family: Arial, Helvetica, sans-serif;
  font-size: 120%;
}

h1 { margin: 14px 0em 1.2em 0em; font-size: 112%; line-height: 130%;}
h2 { font-size: 125%; line-height: 84%;}
h3 { margin-top: 1.4em; font-size: 81%; }
h4 { margin-top: 1em; font-size: 70%; }
h5 { margin-top: 1em; font-size: 100%; font-style: italic;}
h1 strong, h2 strong, h3 strong, h4 strong { font-weight: bold; }

p { margin: 6px 0em 6px 0em; max-width: 55em;}
p.code, code {}
p { font-size: 70%; line-height: 125%; }
table { font-size: 70%;}

p.copyright, .small { font-size: 60%; line-height: 120%; }
p.copyright { margin: 3px 0px 0px 0px; padding: 0px; text-align: left; }
acronym { font-variant: small-caps; }
div.pad { padding: 3px; }
span.lineEndings { color: red; font-size: 70%; }

table.mgRowGroup, table.mgRowGroupFolder { border: 1px solid <xsl:value-of select="$gs_bgBorder"/>; margin: 10px 0px 10px 0px; width: 100%; table-layout: fixed; border-collapse: collapse; }
table.mgRowGroup td { vertical-align: top; padding: 0; }
table.mgRowGroupFolder td { vertical-align: top; padding: 1px 0 1px 0; }
div.IP { width: 2px; height: 1em; float: left; }

img.mgFldrIcon {float: left; text-align: left; margin: -1px 2px 0px 0px;  height: 16px; width: 16px; border: none; vertical-align: top; background-color: transparent;}
div.mgFldrIcon {float: left; width: auto;}
span.left {float: left;width: auto;}
span.right {float: right;width: auto;}

table.bordered { border-collapse: collapse; border: 1px solid <xsl:value-of select="$gs_bgBorder"/>; margin: 10px 0px 10px 0px;}
table.bordered th, table.bordered td { vertical-align: top; padding: 3px; border: 1px solid <xsl:value-of select="$gs_bgBorder"/>;}
table.bordered th { background-color: <xsl:value-of select="$gs_bgHead"/>; }
table.bordered td.group { background-color: <xsl:value-of select="$gs_bgGroup"/>; }
span.disabledNavigation { color: <xsl:value-of select="$gs_bgBorder"/>; }
div.navigation { margin-top: 14px; font-size: 70%; }
				
                <xsl:apply-templates select="/mg:report/mg:metaData/mg:classes"/>
span.selected { background-color: highlight; color: highlighttext; }
span.selected a {background-color: highlight; color: highlighttext; text-decoration: underline; }
			</style>
        </head>
    </xsl:template>


    <xsl:template name="mg:headStatistics">
        <head>
            <meta content="text/html; charset=UCS-2" http-equiv="Content-Type"/>
            <xsl:if test="/mg:report/mg:metaData/mg:title">
                <title>
                    <xsl:call-template name="mg:reportTitleText"/>
                </title>
            </xsl:if>
            <style type="text/css">
input, body, h3, h4, h5, p, ol, ul, li, td, th { font-family: "MS Shell Dlg",Verdana, Arial, Helvetica, sans-serif; font-size: 8pt; }
h3 { margin-top: 1.4 em; margin-bottom: 0 em;}
td, th { text-align: left; }
body { background-color: window;  color: windowtext; margin: 0px 14px 14px 14px; }
th { background-color: inactivecaption; color: inactivecaptiontext; }
table.bordered  { border-collapse: collapse; border: 1px solid threeddarkshadow; margin: 10px 0px 10px 0px; }
table.bordered tr th, table.bordered tr td { vertical-align: top; padding: 3px; border: 1px solid threeddarkshadow; }
p { margin: 6px 0em 6px 0em;  }
table.bordered tr td.group { background-color: buttonface; }
</style>
        </head>
    </xsl:template>


    <xsl:template name="mg:reportTitleText">
        <xsl:if test="/mg:report/mg:metaData/mg:id[@show = 'true']">
            <xsl:value-of select="/mg:report/mg:metaData/mg:id"/>
            <xsl:text>. </xsl:text>
        </xsl:if>
        <xsl:choose>
            <xsl:when test="/mg:report[@type='FileComparison']"><xsl:value-of select="$gl_fileComparisonReportTitle"/></xsl:when>
            <xsl:when test="/mg:report[@type='FolderComparison']"><xsl:value-of select="$gl_folderComparisonReportTitle"/></xsl:when>
            <xsl:when test="/mg:report[@type='FileSlideshowSummary']"><xsl:value-of select="$gl_fileSlideshowReportTitle"/></xsl:when>
            <xsl:when test="/mg:report[@type='FileSlideshowSlide']"><xsl:value-of select="$gl_fileSlideshowReportTitle"/></xsl:when>
        </xsl:choose>
        <xsl:if test="/mg:report/mg:metaData/mg:slide"><xsl:value-of select="$gl_slideN"/><xsl:value-of select="/mg:report/mg:metaData/mg:slide/@number"/><xsl:value-of select="$gl_slideNOf"/><xsl:value-of select="/mg:report/mg:metaData/mg:slide/@count"/><xsl:value-of select="$gl_slideNOfNSuffix"/>
        </xsl:if>
    </xsl:template>


    <xsl:template name="mg:pageTitle">

        <h1><strong>
                <xsl:call-template name="mg:reportTitleText"/>
            </strong></h1>
    </xsl:template>


    <xsl:template name="mg:pageTitleSlideshow">

        <!-- IE4's CSS absolute positioning is broken, so we have to use a table to achieve the desired navigation layout -->
        <table style="font-size: 100%;">
            <tr>
                <td style="width: 100%; font-size: 100%">

                    <h1><strong>
                            <xsl:call-template name="mg:reportTitleText"/>
                        </strong></h1>
                </td>
                <td style="vertical-align: baseline; font-size: 100%; ">
                    <div class="navigation">
                        <xsl:apply-templates mode="navigation" select="mg:metaData/mg:slide"/>
                    </div>
                </td>
            </tr>
        </table>
    </xsl:template>


    <xsl:template name="mg:pageNavFooterSlideshow">

        <!-- IE4's CSS absolute positioning is broken, so we have to use a table to achieve the desired navigation layout -->
        <table style="font-size: 100%;">
            <tr>
                <td style="width: 100%;">&#160;</td>
                <td style="vertical-align: baseline; font-size: 100%; ">
                    <div class="navigation">
                        <xsl:apply-templates mode="navigation" select="mg:metaData/mg:slide"/>
                    </div>
                </td>
            </tr>
        </table>
    </xsl:template>


    <xsl:template name="mg:preamble">
        <xsl:copy-of select="$gl_reportPreamble"/>
    </xsl:template>


    <xsl:template name="mg:pageFooter">
        <p class="copyright" style="margin-top: 25px; padding-top: 2px; border-top: solid {$gs_bgBorder} 1px; max-width: none;">
            <xsl:copy-of select="$gl_footer"/>
        </p>
    </xsl:template>


    <xsl:template name="mg:sectionNumber">
        <xsl:param name="number"/>

        <xsl:choose>
            <xsl:when test="/mg:report/mg:metaData/mg:id[@show = 'true']"><xsl:value-of select="/mg:report/mg:metaData/mg:id"/>
                <xsl:text>.</xsl:text><xsl:value-of select="$number"/>
                <xsl:text>&#160;</xsl:text>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="$number"/>
                <xsl:text>. </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

</xsl:stylesheet>